==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/funknown_8h.js <==
var funknown_8h =
[
    [ "FUnknownPtr< I >", "classSteinberg_1_1FUnknownPtr.html", "classSteinberg_1_1FUnknownPtr" ],
    [ "FReleaser", "structSteinberg_1_1FReleaser.html", "structSteinberg_1_1FReleaser" ],
    [ "INLINE_UID", "funknown_8h.html#a8024fad3ea7ecdd1ab3221d15e04aa52", null ],
    [ "DECLARE_UID", "funknown_8h.html#a5e349c26a022f90b3562eeb32976e6ed", null ],
    [ "EXTERN_UID", "funknown_8h.html#a845c8fdb88f7f23c4060134a798a1e7d", null ],
    [ "DECLARE_CLASS_IID", "funknown_8h.html#aae92a855975a91bb846f6e0f906745f1", null ],
    [ "DEF_CLASS_IID", "funknown_8h.html#a8999be9dadfd41e1f563866e01e94d1c", null ],
    [ "INLINE_UID_OF", "funknown_8h.html#aaf419cd3f56488ae59cd1b9c8397377b", null ],
    [ "INLINE_UID_FROM_FUID", "funknown_8h.html#ae43645513f5c72529a3fb6c6d1e76b46", null ],
    [ "DECLARE_FUNKNOWN_METHODS", "funknown_8h.html#acb6e5cc5e226c37c1fca4f5192fb80a2", null ],
    [ "DELEGATE_REFCOUNT", "funknown_8h.html#a6d9d411a27dcc158df8ff1f5e73510d0", null ],
    [ "IMPLEMENT_REFCOUNT", "funknown_8h.html#ae3db5eac4c75b5199dcdc4462b6289aa", null ],
    [ "FUNKNOWN_CTOR", "funknown_8h.html#a2e898abff4a673feaa52f7ed20a42e50", null ],
    [ "FUNKNOWN_DTOR", "funknown_8h.html#ac31390eb834d3acfda3d871db3f9f959", null ],
    [ "QUERY_INTERFACE", "funknown_8h.html#a1884893f6b75952d6e29bcd333f3ea40", null ],
    [ "IMPLEMENT_QUERYINTERFACE", "funknown_8h.html#a023a5c16eb6b8a0057d712343f9d752c", null ],
    [ "IMPLEMENT_FUNKNOWN_METHODS", "funknown_8h.html#a3131ec3273dc17d39bef17154309b893", null ],
    [ "LARGE_INT", "funknown_8h.html#a9cd1730908299276af7bc0baa8c5197e", null ],
    [ "TUID", "funknown_8h.html#a6935af93744bfe4ecc455f274ef1ec36", null ],
    [ "iidEqual", "funknown_8h.html#aa492cc7f50f5f6bfb7bd727a115e211e", null ],
    [ "atomicAdd", "funknown_8h.html#aeab173beb18bb16a5737f9fbe0a45289", null ],
    [ "getTUID", "funknown_8h.html#afd6bc78c280406220f8af5436c191fff", null ]
];

==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/base/funknown_8h.js <==
var funknown_8h =
[
    [ "FUnknownPtr< I >", "classSteinberg_1_1FUnknownPtr.html", "classSteinberg_1_1FUnknownPtr" ],
    [ "FReleaser", "structSteinberg_1_1FReleaser.html", "structSteinberg_1_1FReleaser" ],
    [ "INLINE_UID", "funknown_8h.html#a8024fad3ea7ecdd1ab3221d15e04aa52", null ],
    [ "DECLARE_UID", "funknown_8h.html#a5e349c26a022f90b3562eeb32976e6ed", null ],
    [ "EXTERN_UID", "funknown_8h.html#a845c8fdb88f7f23c4060134a798a1e7d", null ],
    [ "DECLARE_CLASS_IID", "funknown_8h.html#aae92a855975a91bb846f6e0f906745f1", null ],
    [ "DEF_CLASS_IID", "funknown_8h.html#a8999be9dadfd41e1f563866e01e94d1c", null ],
    [ "INLINE_UID_OF", "funknown_8h.html#aaf419cd3f56488ae59cd1b9c8397377b", null ],
    [ "INLINE_UID_FROM_FUID", "funknown_8h.html#ae43645513f5c72529a3fb6c6d1e76b46", null ],
    [ "DECLARE_FUNKNOWN_METHODS", "funknown_8h.html#acb6e5cc5e226c37c1fca4f5192fb80a2", null ],
    [ "DELEGATE_REFCOUNT", "funknown_8h.html#a6d9d411a27dcc158df8ff1f5e73510d0", null ],
    [ "IMPLEMENT_REFCOUNT", "funknown_8h.html#ae3db5eac4c75b5199dcdc4462b6289aa", null ],
    [ "FUNKNOWN_CTOR", "funknown_8h.html#a2e898abff4a673feaa52f7ed20a42e50", null ],
    [ "FUNKNOWN_DTOR", "funknown_8h.html#ac31390eb834d3acfda3d871db3f9f959", null ],
    [ "QUERY_INTERFACE", "funknown_8h.html#a1884893f6b75952d6e29bcd333f3ea40", null ],
    [ "IMPLEMENT_QUERYINTERFACE", "funknown_8h.html#a023a5c16eb6b8a0057d712343f9d752c", null ],
    [ "IMPLEMENT_FUNKNOWN_METHODS", "funknown_8h.html#a3131ec3273dc17d39bef17154309b893", null ],
    [ "LARGE_INT", "namespaceSteinberg.html#a9cd1730908299276af7bc0baa8c5197e", null ],
    [ "TUID", "namespaceSteinberg.html#a6935af93744bfe4ecc455f274ef1ec36", null ],
    [ "iidEqual", "namespaceSteinberg_1_1FUnknownPrivate.html#afbf1ba7f286964b19e55474c2905eae4", null ],
    [ "atomicAdd", "namespaceSteinberg_1_1FUnknownPrivate.html#aeab173beb18bb16a5737f9fbe0a45289", null ],
    [ "getTUID", "namespaceSteinberg.html#ab5c714b140d499f304e042e746ca9b1b", null ]
];
